==> mingw-w64-clang-i686-osgbullet-git-3.0.0.265-2-any.pkg.tar.zst: clang32/lib/osgbullet-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "osgbCollision" for configuration "Release"
set_property(TARGET osgbCollision APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgbCollision PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgbCollision.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "osgwTools;osgwQuery;osgwMx;osgwControls;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgShadow.dll.a;${_IMPORT_PREFIX}/lib/libBulletCollision.dll.a;${_IMPORT_PREFIX}/lib/libLinearMath.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgbCollision.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgbCollision )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgbCollision "${_IMPORT_PREFIX}/lib/libosgbCollision.dll.a" "${_IMPORT_PREFIX}/bin/libosgbCollision.dll" )

# Import target "osgbDynamics" for configuration "Release"
set_property(TARGET osgbDynamics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgbDynamics PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgbDynamics.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "osgwTools;osgwQuery;osgwMx;osgwControls;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgShadow.dll.a;${_IMPORT_PREFIX}/lib/libBulletDynamics.dll.a;${_IMPORT_PREFIX}/lib/libBulletCollision.dll.a;${_IMPORT_PREFIX}/lib/libLinearMath.dll.a;${_IMPORT_PREFIX}/lib/libBulletSoftBody.dll.a;osgbCollision"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgbDynamics.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgbDynamics )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgbDynamics "${_IMPORT_PREFIX}/lib/libosgbDynamics.dll.a" "${_IMPORT_PREFIX}/bin/libosgbDynamics.dll" )

# Import target "osgbInteraction" for configuration "Release"
set_property(TARGET osgbInteraction APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgbInteraction PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgbInteraction.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "osgwTools;osgwQuery;osgwMx;osgwControls;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgShadow.dll.a;${_IMPORT_PREFIX}/lib/libBulletDynamics.dll.a;${_IMPORT_PREFIX}/lib/libBulletCollision.dll.a;${_IMPORT_PREFIX}/lib/libLinearMath.dll.a;${_IMPORT_PREFIX}/lib/libBulletSoftBody.dll.a;osgbDynamics;osgbCollision"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgbInteraction.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgbInteraction )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgbInteraction "${_IMPORT_PREFIX}/lib/libosgbInteraction.dll.a" "${_IMPORT_PREFIX}/bin/libosgbInteraction.dll" )

# Import target "osgdb_osgbdynamics" for configuration "Release"
set_property(TARGET osgdb_osgbdynamics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_osgbdynamics PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_osgbdynamics.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgdb_osgbdynamics )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgdb_osgbdynamics "${_IMPORT_PREFIX}/bin/osgdb_osgbdynamics.dll" )

# Import target "osgdb_sgb" for configuration "Release"
set_property(TARGET osgdb_sgb APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_sgb PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_sgb.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgdb_sgb )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgdb_sgb "${_IMPORT_PREFIX}/bin/osgdb_sgb.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-i686-osgbullet-git-3.0.0.265-3-any.pkg.tar.zst: clang32/lib/osgbullet-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "osgbCollision" for configuration "Release"
set_property(TARGET osgbCollision APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgbCollision PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgbCollision.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "osgwTools;osgwQuery;osgwMx;osgwControls;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgShadow.dll.a;${_IMPORT_PREFIX}/lib/libBulletCollision.dll.a;${_IMPORT_PREFIX}/lib/libLinearMath.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgbCollision.dll"
  )

list(APPEND _cmake_import_check_targets osgbCollision )
list(APPEND _cmake_import_check_files_for_osgbCollision "${_IMPORT_PREFIX}/lib/libosgbCollision.dll.a" "${_IMPORT_PREFIX}/bin/libosgbCollision.dll" )

# Import target "osgbDynamics" for configuration "Release"
set_property(TARGET osgbDynamics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgbDynamics PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgbDynamics.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "osgwTools;osgwQuery;osgwMx;osgwControls;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgShadow.dll.a;${_IMPORT_PREFIX}/lib/libBulletDynamics.dll.a;${_IMPORT_PREFIX}/lib/libBulletCollision.dll.a;${_IMPORT_PREFIX}/lib/libLinearMath.dll.a;${_IMPORT_PREFIX}/lib/libBulletSoftBody.dll.a;osgbCollision"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgbDynamics.dll"
  )

list(APPEND _cmake_import_check_targets osgbDynamics )
list(APPEND _cmake_import_check_files_for_osgbDynamics "${_IMPORT_PREFIX}/lib/libosgbDynamics.dll.a" "${_IMPORT_PREFIX}/bin/libosgbDynamics.dll" )

# Import target "osgbInteraction" for configuration "Release"
set_property(TARGET osgbInteraction APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgbInteraction PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgbInteraction.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "osgwTools;osgwQuery;osgwMx;osgwControls;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgShadow.dll.a;${_IMPORT_PREFIX}/lib/libBulletDynamics.dll.a;${_IMPORT_PREFIX}/lib/libBulletCollision.dll.a;${_IMPORT_PREFIX}/lib/libLinearMath.dll.a;${_IMPORT_PREFIX}/lib/libBulletSoftBody.dll.a;osgbDynamics;osgbCollision"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgbInteraction.dll"
  )

list(APPEND _cmake_import_check_targets osgbInteraction )
list(APPEND _cmake_import_check_files_for_osgbInteraction "${_IMPORT_PREFIX}/lib/libosgbInteraction.dll.a" "${_IMPORT_PREFIX}/bin/libosgbInteraction.dll" )

# Import target "osgdb_osgbdynamics" for configuration "Release"
set_property(TARGET osgdb_osgbdynamics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_osgbdynamics PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_osgbdynamics.dll"
  )

list(APPEND _cmake_import_check_targets osgdb_osgbdynamics )
list(APPEND _cmake_import_check_files_for_osgdb_osgbdynamics "${_IMPORT_PREFIX}/bin/osgdb_osgbdynamics.dll" )

# Import target "osgdb_sgb" for configuration "Release"
set_property(TARGET osgdb_sgb APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_sgb PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_sgb.dll"
  )

list(APPEND _cmake_import_check_targets osgdb_sgb )
list(APPEND _cmake_import_check_files_for_osgdb_sgb "${_IMPORT_PREFIX}/bin/osgdb_sgb.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
